@@ -1,6 +1,6 @@
 package PerlX::Let;
 
-# ABSTRACT: Syntactic sugar for lexical constants
+# ABSTRACT: Syntactic sugar for lexical state constants
 
 use v5.12;
 
@@ -11,7 +11,7 @@ use Const::Fast ();
 use Keyword::Simple 0.04;
 use Text::Balanced ();
 
-our $VERSION = 'v0.2.5';
+our $VERSION = 'v0.2.6';
 
 
 sub import {
@@ -86,11 +86,11 @@ __END__
 
 =head1 NAME
 
-PerlX::Let - Syntactic sugar for lexical constants
+PerlX::Let - Syntactic sugar for lexical state constants
 
 =head1 VERSION
 
-version v0.2.5
+version v0.2.6
 
 =head1 SYNOPSIS
 
@@ -119,28 +119,50 @@ is liable to typos. You could simplify it with
 
   let $key = "username" {
 
-    if (defined $arg{$key}) {
-      $row->update( { $key => $arg{$key} );
-    }
+      if (defined $arg{$key}) {
+          $row->update( { $key => $arg{$key} );
+      }
 
   }
 
 This is roughly equivalent to using
 
-  use Const::Fast;
+  use Const::Fast ();
 
   {
-    const $key => "username";
+      use feature 'state';
 
-    if (defined $arg{$key}) {
-      $row->update( { $key => $arg{$key} );
-    }
+      state $key = "username";
+
+      unless (state $_flag = 0) {
+          Const::Fast::_make_readonly( \$key );
+          $_flag = 1;
+      }
+
+      if (defined $arg{$key}) {
+          $row->update( { $key => $arg{$key} );
+      }
 
   }
 
-However, if the value does not contain a sigil, and the variable is a
-scalar, or you are using Perl v5.28 or later, this uses state
-variables so that the value is only set once.
+However, if the value contains a sigil, or (for versions of Perl
+before 5.28) the value is not a scalar, then this uses a my variable
+variable
+
+  use Const::Fast ();
+
+  {
+      Const::Fast::const my $key => "username";
+
+      if (defined $arg{$key}) {
+          $row->update( { $key => $arg{$key} );
+      }
+  }
+
+The reason for using state variables is that it takes time to mark a
+variable as read-only, particularly for deeper data structures.
+However, the tradeoff for using this is that the variables remain
+allocated until the process exits.
 
 If the code block is omitted, then this can be used to declare a
 state constant in the current scope, e.g.
@@ -149,16 +171,23 @@ state constant in the current scope, e.g.
 
   say $x;
 
+Note that this may enable the state L<feature> in the current scope.
+
 =head1 KNOWN ISSUES
 
 The parsing of assignments is rudimentary, and may fail when assigning
-to another variable or the result of a function.
+to another variable or the result of a function.  Because of this,
+you may get unusual error messages for syntax errors, e.g.
+"Transliteration pattern not terminated".
 
 Because this modifies the source code during compilation, the line
-numbers may be changed.
+numbers may be changed, particularly if the let assignment(s) are on
+multiple lines.
 
 =head1 SEE ALSO
 
+L<feature>
+
 L<Const::Fast>
 
 L<Keyword::Simple>
